pub enum BorrowState {
Reading,
Writing,
Unused,
}An enumeration of values returned from the state method on a RefCell<T>.
Variants
Reading | The cell is currently being read, there is at least one active borrow.
|
Writing | The cell is currently being written to, there is an active borrow_mut.
|
Unused | There are no outstanding borrows on this cell.
|